grplot: lazy statistical data visualization
=======================================

grplot is a Python visualization library based on numpy, scipy, matplotlib, seaborn, squarify, and pandas. It supports human laziness in drawing complete and attractive statistical graphs.


Documentation
-------------

Online documentation is available at [grplot repository](https://github.com/ghiffaryr/grplot).

The docs include an [example](https://github.com/ghiffaryr/grplot/blob/main/doc/example/example.ipynb) and other useful information.

Offline documentation can be accesed through Python:

	help(grplot)


Dependencies
------------

grplot supports Python 3.6+.

Installation requires [numpy](https://numpy.org), [scipy](https://www.scipy.org), [matplotlib](https://matplotlib.org), [seaborn](https://seaborn.pydata.org), and [pandas](https://pandas.pydata.org). Some functions will optionally use [statsmodels](https://www.statsmodels.org) if it is installed.


Installation
------------

The latest stable release (and required dependencies) can be installed from PyPI:

    pip install grplot


Development
-----------

grplot development takes place on Github: https://github.com/ghiffaryr/grplot/tree/dev

Please submit bugs that you encounter to the [issue tracker](https://github.com/ghiffaryr/grplot/issues) with a reproducible example demonstrating the problem.

